#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class DeviceSim(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DeviceSim
                | 
                | Interface allowing simulation of a Device.
                | 
                | Role: This interface is used to simulate the devices that are available in the
                | Device Building workbench. This includes devices created in both V5 and
                | D5.
                | The following code snippet can be used to obtain a device in a CATProduct
                | document.
                | 
                |    Dim objDeviceSim As DeviceSim
                |    Set objDeviceSim = CATIA.ActiveDocument.Product.GetTechnologicalObject("DeviceSim")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.device_sim = com_object

    def finalize(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Finalize()
                | 
                |     Cleans the WDM world. Please note that no reference counting will be
                |     maintained. Cleanup should be done on each device before another device is
                |     Initialized
                | 
                |     Returns:
                |         an HRESULT value.
                |
                |     Example:
                |
                |            Dim objDeviceSim As DeviceSim
                |            Set objDeviceSim = CATIA.ActiveDocument.Product.GetTechnologicalObject("DeviceSim")
                |            objDeviceSim.Initialize
                |            ...
                |            objDevice.Finalize

        :rtype: None
        """
        return self.device_sim.Finalize()

    def get_dof_values(self, i_mechanism: AnyObject) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDOFValues(CATBaseDispatch iMechanism) As
                | CATSafeArrayVariant
                | 
                |     Get the DOF values for the device.
                | 
                |     Parameters:
                | 
                |         iMechanism
                |             This inner parameter contains a handle to the mechanism
                |             
                |         oValues
                |             This outer parameter contains a list of the current DOF values.
                |             Please note that distances are measured in meters and angles in radians.
                |             
                | 
                |     Returns:
                |         an HRESULT value.
                |
                |     Example:
                |
                |            Dim  ListMechanisms  As Mechanisms
                |            Set  ListMechanisms  =  CATIA.ActiveDocument.Product.GetTechnologicalObject("Mechanisms")
                |            On Error Resume Next
                |            Dim mech
                |            Set mech = ListMechanisms.Item(1)
                |            If Err.Number <> 0 Then
                |               'If there are no mechanisms (i.e. D5 devices), use the device sim
                |               handle instead
                |               Set mech = CATIA.ActiveDocument.Product.GetTechnologicalObject("DeviceSim")
                |            End If    
                |            On Error GoTo 0
                | 
                |            Dim objDeviceSim As DeviceSim
                |            Set objDeviceSim = CATIA.ActiveDocument.Product.GetTechnologicalObject("DeviceSim")
                |            objDeviceSim.Initialize
                |            
                |            Dim ListOfDOFValues
                |            ListOfDOFValues = objDevice.GetDOFValues (mech)
                |            ...

        :param AnyObject i_mechanism:
        :rtype: tuple
        """
        return self.device_sim.GetDOFValues(i_mechanism.com_object)

    def initialize(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Initialize()
                | 
                |     Initializes the WDM world. Required for calls to
                |     Get/SetDOFValues
                | 
                |     Returns:
                |         an HRESULT value.
                |
                |     Example:
                |
                |            Dim objDeviceSim As DeviceSim
                |            Set objDeviceSim = CATIA.ActiveDocument.Product.GetTechnologicalObject("DeviceSim")
                |            objDeviceSim.Initialize

        :rtype: None
        """
        return self.device_sim.Initialize()

    def set_dof_values(self, i_mechanism: AnyObject, i_values: tuple, i_is_relative: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDOFValues(CATBaseDispatch iMechanism,
                | CATSafeArrayVariant iValues,
                | boolean iIsRelative)
                | 
                |     Set the DOF values for the device.
                | 
                |     Parameters:
                | 
                |         iValues
                |             This inner parameter contains a list of the DOF values to be
                |             applied. Size of iValues should be equal to the number of DOFs. Please note
                |             that distances are measured in meters and angles in radians.
                |             
                |         iMechanism
                |             This inner parameter contains a handle to the mechanism. For D5
                |             devices the device itself should be used as the mechanism (sample below)
                |             
                |         iIsRelative
                |             This inner parameter indicates if iValues is relative to the
                |             existing DOF values. If set to TRUE, iValues will be added to the existing
                |             values 
                | 
                |     Returns:
                |         an HRESULT value.
                |
                |     Example:
                |
                |            Dim  ListMechanisms  As Mechanisms
                |            Set  ListMechanisms  =  CATIA.ActiveDocument.Product.GetTechnologicalObject("Mechanisms")
                |            On Error Resume Next
                |            Dim mech
                |            Set mech = ListMechanisms.Item(1)
                |            If Err.Number <> 0 Then
                |               'If there are no mechanisms (i.e. D5 devices), use the device
                |               handle instead
                |               Set mech = CATIA.ActiveDocument.Product.GetTechnologicalObject("DeviceSim")
                |            End If    
                |            On Error GoTo 0
                | 
                |            Dim objDeviceSim As DeviceSim
                |            Set objDeviceSim = CATIA.ActiveDocument.Product.GetTechnologicalObject("DeviceSim")
                |            objDeviceSim.Initialize
                |            Dim ListOfDOFValues (5) 
                |            'Populate ListOfDOFValues with some values
                |            ...
                |            objDevice.SetDOFValues mech, ListOfDOFValues, TRUE
                |            ...

        :param AnyObject i_mechanism:
        :param tuple i_values:
        :param bool i_is_relative:
        :rtype: None
        """
        return self.device_sim.SetDOFValues(i_mechanism.com_object, i_values, i_is_relative)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_dof_values'
        # # vba_code = """
        # # Public Function set_dof_values(device_sim)
        # #     Dim iMechanism (2)
        # #     device_sim.SetDOFValues iMechanism
        # #     set_dof_values = iMechanism
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'DeviceSim(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_igp_setup_interfaces.tag_group import TagGroup
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject


class TagGroupFactory(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     TagGroupFactory
                | 
                | Interface representing TagGroup factory.
                | 
                | Role: This allows the creation of a TagGroup
                | The following code snippet can be used to obtain a TagGroupFactory from a
                | selected Product
                | 
                |   Set ParentObject = CATIA.ActiveDocument.Selection.FindObject("CATIAProduct")	
                |   Set objTagGroupFact = ParentObject.GetTechnologicalObject("TagGroupFactory")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.tag_group_factory = com_object

    def copy_tag_group(self, i_tag_group: TagGroup, io_tag_group: TagGroup) -> TagGroup:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CopyTagGroup(TagGroup iTagGroup,
                | TagGroup ioTagGroup)
                | 
                |     Copies a TagGroup to a new Product
                | 
                |     Parameters:
                | 
                |         iTagGroup
                |             TagGroup to be copied. 
                |         ioTagGroup
                |             The TagGroup to which iTagGroup gets copied 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise
                |
                |     Example:
                |
                |           ...
                |           Dim objTagGroup(2) As TagGroup
                |           Dim objTagGroupFactory as TagGroupFactory
                |           ...
                |           objTagGroupFactory.CopyTagGroup objTagGroup(1),
                |           objTagGroup(2)

        :param TagGroup i_tag_group:
        :param TagGroup io_tag_group:
        :rtype: TagGroup
        """
        return TagGroup(self.tag_group_factory.CopyTagGroup(i_tag_group.com_object, io_tag_group.com_object))
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'copy_tag_group'
        # # vba_code = """
        # # Public Function copy_tag_group(tag_group_factory)
        # #     Dim iTagGroup (2)
        # #     tag_group_factory.CopyTagGroup iTagGroup
        # #     copy_tag_group = iTagGroup
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def create_tag_group(
            self,
            i_tag_group_name: str,
            i_modify_reference: bool,
            i_product: Product,
            o_tag_group: TagGroup
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateTagGroup(CATBSTR iTagGroupName,
                | boolean iModifyReference,
                | Product iProduct,
                | TagGroup oTagGroup)
                | 
                |     Creates a TagGroup. Each TagGroup has a Name, an option to modify reference
                |     or modify locally and, the reference product.
                | 
                |     Parameters:
                | 
                |         iTagGroupName
                |             Name of the TagGroup to be created. 
                |         iModifyReference
                |             Modify reference or modify locally. 
                |         iProduct
                |             Reference product. 
                |         oTagGroup
                |             Created TagGroup. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             Action is successfully created and the interface pointer is
                |             successfully returned
                |         E_FAIL
                |             Action was successfully created, but the interface query
                |             failed
                |         E_NOINTERFACE
                |             Action was successfully created, but the it doesn't implement the
                |             requested interface
                |         E_OUTOFMEMORY
                |             The component allocation failed
                | 
                |     Example:
                |
                |            Set ParentObject = CATIA.ActiveDocument.Selection.FindObject("CATIAProduct")
                |            Set objTagGroupFact = ParentObject.GetTechnologicalObject("TagGroupFactory")
                | 
                |            Dim objTagGroup As TagGroup
                |            Dim ModifyRef As Boolean
                | 
                |            ModifyRef = FALSE
                |            objTagGroupFact.CreateTagGroup "My_Group", ModifyRef, ParentObject,
                |            objTagGroup

        :param str i_tag_group_name:
        :param bool i_modify_reference:
        :param Product i_product:
        :param TagGroup o_tag_group:
        :rtype: None
        """
        return self.tag_group_factory.CreateTagGroup(
            i_tag_group_name,
            i_modify_reference,
            i_product.com_object,
            o_tag_group.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_tag_group'
        # # vba_code = """
        # # Public Function create_tag_group(tag_group_factory)
        # #     Dim iTagGroupName (2)
        # #     tag_group_factory.CreateTagGroup iTagGroupName
        # #     create_tag_group = iTagGroupName
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def create_tag_group_in_doc(self, i_tag_group_name: str, o_tag_group: TagGroup) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateTagGroupInDoc(CATBSTR iTagGroupName,
                | TagGroup oTagGroup)
                | 
                |     Creates a TagGroup with the given name in the document.
                | 
                |     Parameters:
                | 
                |         iTagGroupName
                |             Name of the TagGroup to be created. 
                |         oTagGroup
                |             Created TagGroup. 
                | 
                |     Returns:
                |         An HRESULT.
                |         Legal values:
                | 
                |         S_OK
                |             Action is successfully created and the interface pointer is
                |             successfully returned
                |         E_FAIL
                |             Action was successfully created, but the interface query
                |             failed
                |         E_NOINTERFACE
                |             Action was successfully created, but the it doesn't implement the
                |             requested interface
                |         E_OUTOFMEMORY
                |             The component allocation failed
                | 
                |     Example:
                |
                |            Set ParentObject = CATIA.ActiveDocument
                |            Dim Fact As TagGroupFactory
                |            Set Fact = ParentObject.GetItem("DELMTagGroupFactory")
                |            Dim TagGrp As TagGroup
                |            Fact.CreateTagGroupInDoc "ABC", TagGrp

        :param str i_tag_group_name:
        :param TagGroup o_tag_group:
        :rtype: None
        """
        return self.tag_group_factory.CreateTagGroupInDoc(i_tag_group_name, o_tag_group.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_tag_group_in_doc'
        # # vba_code = """
        # # Public Function create_tag_group_in_doc(tag_group_factory)
        # #     Dim iTagGroupName (2)
        # #     tag_group_factory.CreateTagGroupInDoc iTagGroupName
        # #     create_tag_group_in_doc = iTagGroupName
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def delete_tag_group(self, i_tag_group: TagGroup) -> TagGroup:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub DeleteTagGroup(TagGroup iTagGroup)
                | 
                |     Deletes a TagGroup
                | 
                |     Parameters:
                | 
                |         iTagGroup
                |             TagGroup to be deleted 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise
                |
                |     Example:
                |
                |           ...
                |           Dim objTagGroup(2) As TagGroup
                |           Dim objTagGroupFactory as TagGroupFactory
                |           ...
                |           objTagGroupFactory.DeleteTagGroup objTagGroup(1)

        :param TagGroup i_tag_group:
        :rtype: TagGroup
        """
        return TagGroup(self.tag_group_factory.DeleteTagGroup(i_tag_group.com_object))
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'delete_tag_group'
        # # vba_code = """
        # # Public Function delete_tag_group(tag_group_factory)
        # #     Dim iTagGroup (2)
        # #     tag_group_factory.DeleteTagGroup iTagGroup
        # #     delete_tag_group = iTagGroup
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def reparent_tag_group(self, i_tag_group: TagGroup, io_product: Product, i_modify_reference: bool) -> TagGroup:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ReparentTagGroup(TagGroup iTagGroup,
                | Product ioProduct,
                | boolean iModifyReference)
                | 
                |     Reparents a TagGroup
                | 
                |     Parameters:
                | 
                |         iTagGroup
                |             TagGroup to be reparented. 
                |         ioProduct
                |             The Product to which the TagGroup gets reparented 
                |         iModifyReference
                |             Modify reference or modify locally. 
                | 
                |     Returns:
                |         an HRESULT value.
                |         Legal values:
                | 
                |             S_OK if the operation succeeds
                |             E_FAIL otherwise
                |
                |     Example:
                |
                |           ...
                |           Dim objTagGroup(2) As TagGroup
                |           Dim objTagGroupFactory as TagGroupFactory
                |           Dim objProd As Product
                |           ...
                |           objTagGroupFactory.ReparentTagGroup objTagGroup(0), objProd,
                |           TRUE

        :param TagGroup i_tag_group:
        :param Product io_product:
        :param bool i_modify_reference:
        :rtype: TagGroup
        """
        return TagGroup(
            self.tag_group_factory.ReparentTagGroup(
                i_tag_group.com_object,
                io_product.com_object,
                i_modify_reference
            )
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'reparent_tag_group'
        # # vba_code = """
        # # Public Function reparent_tag_group(tag_group_factory)
        # #     Dim iTagGroup (2)
        # #     tag_group_factory.ReparentTagGroup iTagGroup
        # #     reparent_tag_group = iTagGroup
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'TagGroupFactory(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_app_connector import SchAppConnector
from pycatia.cat_sch_platform_interfaces.sch_comp_group_ext import SchCompGroupExt
from pycatia.cat_sch_platform_interfaces.sch_component import SchComponent
from pycatia.cat_sch_platform_interfaces.sch_grr_comp import SchGRRComp
from pycatia.cat_sch_platform_interfaces.sch_list_of_objects import SchListOfObjects
from pycatia.cat_sch_platform_interfaces.sch_route import SchRoute
from pycatia.cat_sch_platform_interfaces.sch_zone import SchZone
from pycatia.system_interfaces.any_object import AnyObject


class SchBaseFactory(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchBaseFactory
                | 
                | Factory to create basic schematic objects.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_base_factory = com_object

    def create_network(self, i_l_cntbls: SchListOfObjects, i_lgr_rs: SchListOfObjects) -> SchListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateNetwork(SchListOfObjects iLCntbls,
                | SchListOfObjects iLGRRs) As SchListOfObjects
                | 
                |     Create schematic networks for query. These are volatile objects and will
                |     not be saved in the model.
                | 
                |     Parameters:
                | 
                |         iLCntbl
                |             A list of related objects that belong to the network
                |             (CATISchAppConnectable pointers). These objects do not need to be connected.
                |             This method will do the analysis and returns the network(s) containing these
                |             objects. 
                |         iLCntbl
                |             A list of graphical images interface (CATISchGRR) pointers. Each
                |             member corresponds to the members in iLCntbl. 
                |         oNetwork
                |             [out, IUnknown#Release] Pointer to the network analysis interface
                |             pointers. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchBaseFactory
                |          Dim objArg1 As SchListOfObjects
                |          Dim objArg2 As SchListOfObjects
                |          Dim objArg3 As SchListOfObjects
                |           ...
                |          Set objArg3 = objThisIntf.CreateNetwork(objArg1,objArg2)

        :param SchListOfObjects i_l_cntbls:
        :param SchListOfObjects i_lgr_rs:
        :rtype: SchListOfObjects
        """
        return SchListOfObjects(self.sch_base_factory.CreateNetwork(i_l_cntbls.com_object, i_lgr_rs.com_object))

    def create_route_and_connect_to_objects(
            self,
            i_app_route: AnyObject,
            i_cntr_comp_from: SchAppConnector,
            i_cntr_comp_to: SchAppConnector,
            i_grr_comp_from: SchGRRComp,
            i_grr_comp_to: SchGRRComp,
            i_l_db2_pt_path: tuple,
            i_e_route_mode: int,
            o_sch_route: SchRoute
    ) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateRouteAndConnectToObjects(AnyObject iAppRoute,
                | SchAppConnector iCntrCompFrom,
                | SchAppConnector iCntrCompTo,
                | SchGRRComp iGRRCompFrom,
                | SchGRRComp iGRRCompTo,
                | CATSafeArrayVariant iLDb2PtPath,
                | CatSchIDLRouteMode iERouteMode,
                | SchRoute oSchRoute)
                | 
                |     Create a route and connect its extremity connectors to input
                |     objects.
                | 
                |     Parameters:
                | 
                |         iAppRoute
                |             Application route (at least a feature) 
                |         iCntrCompFrom
                |             Pointer to component connector to connect starting end of the route
                |             to If NULL, no connection is made at this end. 
                |         iCntrCompTo
                |             Pointer to component connector to connect end of the route to If
                |             NULL, no connection is made at this end. 
                |         iGRRCompFrom
                |             Pointer to first component graphical image, if NULL, the PRIMARY
                |             image associated with component will be used 
                |         iGRRCompTo
                |             Pointer to second component graphical image, if NULL, the PRIMARY
                |             image associated with component will be used 
                |         iLDb2PtPath
                |             A list of X-Y coordinates of points to be used for the route image.
                |             2 doubles per point. Not used if iERouteMode=SchRouteMode_AroundObject input a
                |             NULL for this case 
                |         iERouteMode
                |             Route mode to use. Only used when iLDb2PtPath is NULL.
                |             
                |         oSchRoute
                |             Pointer to the new route 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchBaseFactory
                |          Dim objArg1 As AnyObject
                |          Dim objArg2 As SchAppConnector
                |          Dim objArg3 As SchAppConnector
                |          Dim objArg4 As SchGRRComp
                |          Dim objArg5 As SchGRRComp
                |          Dim dbVar6(x) As CATSafeArrayVariant
                | 
                |          Dim objArg9 As SchRoute
                |           ...
                |         objThisIntf.CreateRouteAndConnectToObjectsobjArg1,objArg2,objArg3,objArg4,objArg5,dbVar6,CatSchIDLRouteMode_Enum,objArg9

        :param AnyObject i_app_route:
        :param SchAppConnector i_cntr_comp_from:
        :param SchAppConnector i_cntr_comp_to:
        :param SchGRRComp i_grr_comp_from:
        :param SchGRRComp i_grr_comp_to:
        :param tuple i_l_db2_pt_path:
        :param int i_e_route_mode: enum cat_sch_idl_route_mode
        :param SchRoute o_sch_route:
        :rtype: tuple
        """
        return self.sch_base_factory.CreateRouteAndConnectToObjects(
            i_app_route.com_object,
            i_cntr_comp_from.com_object,
            i_cntr_comp_to.com_object,
            i_grr_comp_from.com_object,
            i_grr_comp_to.com_object,
            i_l_db2_pt_path,
            i_e_route_mode, o_sch_route.com_object
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_route_and_connect_to_objects'
        # # vba_code = """
        # # Public Function create_route_and_connect_to_objects(sch_base_factory)
        # #     Dim iAppRoute (2)
        # #     sch_base_factory.CreateRouteAndConnectToObjects iAppRoute
        # #     create_route_and_connect_to_objects = iAppRoute
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def create_sch_comp_group(
            self,
            i_app_group: AnyObject,
            i_lgrr: SchListOfObjects,
            i_l_member: SchListOfObjects
    ) -> SchCompGroupExt:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateSchCompGroup(AnyObject iAppGroup,
                | SchListOfObjects iLGRR,
                | SchListOfObjects iLMember) As SchCompGroupExt
                | 
                |     Create a Schematic Component Group object.
                | 
                |     Parameters:
                | 
                |         iAppGroup
                |             Application group object (at least a feature) Optional, it could be
                |             NULL. If NULL, one will be created by the platform
                |             
                |         iLGRR
                |             A list of graphical representation. Optional, it could be NULL.
                |             
                |         iLMembers
                |             A list of initial members. Optional, it could be NULL.
                |             
                |         oSchGroup
                |             Pointer to the new group. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchBaseFactory
                |          Dim objArg1 As AnyObject
                |          Dim objArg2 As SchListOfObjects
                |          Dim objArg3 As SchListOfObjects
                |          Dim objArg4 As SchCompGroupExt
                |           ...
                |          Set objArg4 = objThisIntf.CreateSchCompGroup(objArg1,objArg2,objArg3)

        :param AnyObject i_app_group:
        :param SchListOfObjects i_lgrr:
        :param SchListOfObjects i_l_member:
        :rtype: SchCompGroupExt
        """
        return SchCompGroupExt(
            self.sch_base_factory.CreateSchCompGroup(
                i_app_group.com_object,
                i_lgrr.com_object,
                i_l_member.com_object
            )
        )

    def create_sch_component(
            self,
            i_app_component_ref: AnyObject,
            i_lgrr: SchListOfObjects
    ) -> SchComponent:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateSchComponent(AnyObject iAppComponentRef,
                | SchListOfObjects iLGRR) As SchComponent
                | 
                |     Create a Schematic Component reference.
                | 
                |     Parameters:
                | 
                |         iAppComponentRef
                |             Application component reference (at least a feature)
                |             
                |         iLGRR
                |             A list of graphical representations. 
                |         oSchComp
                |             Pointer to the new component. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchBaseFactory
                |          Dim objArg1 As AnyObject
                |          Dim objArg2 As SchListOfObjects
                |          Dim objArg3 As SchComponent
                |           ...
                |          Set objArg3 = objThisIntf.CreateSchComponent(objArg1,objArg2)

        :param AnyObject i_app_component_ref:
        :param SchListOfObjects i_lgrr:
        :rtype: SchComponent
        """
        return SchComponent(self.sch_base_factory.CreateSchComponent(i_app_component_ref.com_object, i_lgrr.com_object))

    def create_sch_route_by_points(self, i_app_route: AnyObject, i_l_db_pt: tuple, o_sch_route: SchRoute) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateSchRouteByPoints(AnyObject iAppRoute,
                | CATSafeArrayVariant iLDbPt,
                | SchRoute oSchRoute)
                | 
                |     Create a Schematic Route object with a list of points.
                | 
                |     Parameters:
                | 
                |         iAppRoute
                |             Application route (at least a feature) 
                |         iLDbPt
                |             A list of X-Y coordinates of points. 2 doubles per point.
                |             
                |         oSchRoute
                |             Pointer to the new route 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchBaseFactory
                |          Dim objArg1 As AnyObject
                |          Dim dbVar2(x) As CATSafeArrayVariant
                |          Dim objArg4 As SchRoute
                |           ...
                |         objThisIntf.CreateSchRouteByPointsobjArg1,dbVar2,objArg4

        :param AnyObject i_app_route:
        :param tuple i_l_db_pt:
        :param SchRoute o_sch_route:
        :rtype: tuple
        """
        return self.sch_base_factory.CreateSchRouteByPoints(i_app_route.com_object, i_l_db_pt, o_sch_route.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_sch_route_by_points'
        # # vba_code = """
        # # Public Function create_sch_route_by_points(sch_base_factory)
        # #     Dim iAppRoute (2)
        # #     sch_base_factory.CreateSchRouteByPoints iAppRoute
        # #     create_sch_route_by_points = iAppRoute
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def create_sch_route_by_prim(self, i_app_route: AnyObject, i_lgrr: SchListOfObjects) -> SchRoute:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateSchRouteByPrim(AnyObject iAppRoute,
                | SchListOfObjects iLGRR) As SchRoute
                | 
                |     Create a Schematic Route object with primitives.
                | 
                |     Parameters:
                | 
                |         iAppRoute
                |             Application route (at least a feature) 
                |         iLGRR
                |             A list of graphical primitives. pointer). 
                |         oSchRoute
                |             Pointer to the new route 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchBaseFactory
                |          Dim objArg1 As AnyObject
                |          Dim objArg2 As SchListOfObjects
                |          Dim objArg3 As SchRoute
                |           ...
                |          Set objArg3 = objThisIntf.CreateSchRouteByPrim(objArg1,objArg2)

        :param AnyObject i_app_route:
        :param SchListOfObjects i_lgrr:
        :rtype: SchRoute
        """
        return SchRoute(self.sch_base_factory.CreateSchRouteByPrim(i_app_route.com_object, i_lgrr.com_object))

    def create_sch_zone(self, i_app_zone: AnyObject, i_lgrr: SchListOfObjects) -> SchZone:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateSchZone(AnyObject iAppZone,
                | SchListOfObjects iLGRR) As SchZone
                | 
                |     Create a Schematic Zone object.
                | 
                |     Parameters:
                | 
                |         iAppZone
                |             Application zone object (at least a feature) 
                |         iLGRR
                |             A list of graphical representation. 
                |         oSchZone
                |             Pointer to the new zone. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchBaseFactory
                |          Dim objArg1 As AnyObject
                |          Dim objArg2 As SchListOfObjects
                |          Dim objArg3 As SchZone
                |           ...
                |          Set objArg3 = objThisIntf.CreateSchZone(objArg1,objArg2)

        :param AnyObject i_app_zone:
        :param SchListOfObjects i_lgrr:
        :rtype: SchZone
        """
        return SchZone(self.sch_base_factory.CreateSchZone(i_app_zone.com_object, i_lgrr.com_object))

    def delete_object(self, i_object: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub DeleteObject(AnyObject iObject)
                | 
                |     Delete a schematic object.
                | 
                |     Parameters:
                | 
                |         iObject
                |             interface pointer to the object to be deleted 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchBaseFactory
                |          Dim objArg1 As AnyObject
                |           ...
                |          objThisIntf.DeleteObjectobjArg1

        :param AnyObject i_object:
        :rtype: None
        """
        return self.sch_base_factory.DeleteObject(i_object.com_object)

    def __repr__(self):
        return f'SchBaseFactory(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_load import ABQLoad
from pycatia.mec_mod_interfaces.axis_system import AxisSystem
from pycatia.product_structure_interfaces.product import Product
from pycatia.product_structure_interfaces.publication import Publication


class ABQGravity(ABQLoad):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ABQAutomationItf.ABQLoad
                |                         ABQGravity
                | 
                | Represents an Abaqus gravity (ABQGravity) object.
                | Role: Access an Abaqus gravity load object or determine its
                | properties.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.abq_gravity = com_object

    @property
    def use_local_csys(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UselocalCsys() As boolean
                | 
                |     Sets or returns a boolean indicating whether local coordinate system is
                |     used in Gravity load.
                | 
                |     Returns:
                |         boolean specifying whether local csys is active.

        :rtype: bool
        """

        return self.abq_gravity.UselocalCsys

    @use_local_csys.setter
    def use_local_csys(self, value: bool):
        """
        :param bool value:
        """

        self.abq_gravity.UselocalCsys = value

    @property
    def comp1(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property comp1() As double
                | 
                |     Sets or returns the gravity component in the 1-direction.
                | 
                |     Returns:
                |         The gravity component in the 1-direction.

        :rtype: float
        """

        return self.abq_gravity.comp1

    @comp1.setter
    def comp1(self, value: float):
        """
        :param float value:
        """

        self.abq_gravity.comp1 = value

    @property
    def comp2(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property comp2() As double
                | 
                |     Sets or returns the gravity component in the 2-direction.
                | 
                |     Returns:
                |         The gravity component in the 2-direction.

        :rtype: float
        """

        return self.abq_gravity.comp2

    @comp2.setter
    def comp2(self, value: float):
        """
        :param float value:
        """

        self.abq_gravity.comp2 = value

    @property
    def comp3(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property comp3() As double
                | 
                |     Sets or returns the gravity component in the 3-direction.
                | 
                |     Returns:
                |         The gravity component in the 3-direction.

        :rtype: float
        """

        return self.abq_gravity.comp3

    @comp3.setter
    def comp3(self, value: float):
        """
        :param float value:
        """

        self.abq_gravity.comp3 = value

    @property
    def local_csys(self) -> AxisSystem:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property localCsys() As AxisSystem
                | 
                |     Sets or returns the local coordinate system of the gravity
                |     load.
                | 
                |     Returns:
                |         The local coordinate system.

        :rtype: AxisSystem
        """

        return AxisSystem(self.abq_gravity.localCsys)

    @local_csys.setter
    def local_csys(self, value: AxisSystem):
        """
        :param AxisSystem value:
        """

        self.abq_gravity.localCsys = value

    def get_local_csys_from_publication(self, o_product: Product, o_pub_axis_system: AxisSystem) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetLocalCsysFromPublication(Product oProduct,
                | AxisSystem oPubAxisSystem)
                | 
                |     Gets the published local coordinate system of the gravity
                |     load.
                | 
                |     Parameters:
                | 
                |         oProduct
                |             The CATIA Product specifying the local coordinate system
                |             publication.
                |         oPubAxisSystem
                |             The CATIA Axis system.
                | 
                |             Refer: CATIAAxisSystem

        :param Product o_product:
        :param AxisSystem o_pub_axis_system:
        :rtype: None
        """
        return self.abq_gravity.GetLocalCsysFromPublication(o_product.com_object, o_pub_axis_system.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_local_csys_from_publication'
        # # vba_code = """
        # # Public Function get_local_csys_from_publication(abq_gravity)
        # #     Dim oProduct (2)
        # #     abq_gravity.GetLocalCsysFromPublication oProduct
        # #     get_local_csys_from_publication = oProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_local_csys_from_publication(self, i_product: Product, i_pub_axis_system: Publication) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetLocalCsysFromPublication(Product iProduct,
                | Publication iPubAxisSystem)
                | 
                |     Sets the published local coordinate system of the gravity
                |     load.
                | 
                |     Returns:
                |         Fails if the publication is not an axis system. 
                |     Parameters:
                | 
                |         iProduct
                |             The CATIA Product specifying the local coordinate system
                |             publication.
                |         iPublication
                |             The CATIA Publication on the axis system.
                | 
                |             Refer: CATIAPublication

        :param Product i_product:
        :param Publication i_pub_axis_system:
        :rtype: None
        """
        return self.abq_gravity.SetLocalCsysFromPublication(i_product.com_object, i_pub_axis_system.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_local_csys_from_publication'
        # # vba_code = """
        # # Public Function set_local_csys_from_publication(abq_gravity)
        # #     Dim iProduct (2)
        # #     abq_gravity.SetLocalCsysFromPublication iProduct
        # #     set_local_csys_from_publication = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ABQGravity(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.funct_system_interfaces.functional_facet_mgr import FunctionalFacetMgr
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class FunctFacetManagers(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     FunctFacetManagers
                | 
                | Represents the Functional Facet's Managers.
    
    """

    def __init__(self, com_object, child_object=FunctionalFacetMgr):
        super().__init__(com_object, child_object=FunctionalFacetMgr)
        self.funct_facet_managers = com_object
        self.child_object = FunctionalFacetMgr

    def elem(self, i_index: cat_variant) -> FunctionalFacetMgr:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Elem(CATVariant iIndex) As FunctionalFacetMgr
                | 
                |     Returns a facet manager using its index or its name from the facet managers
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the facet manager to retrieve from the
                |             collection of facet managers. As a numerics, this index is the rank of the
                |             facet manager in the collection. The index of the first facet manager in the
                |             collection is 1, and the index of the last facet manager is Count. As a string,
                |             it is the name you assigned to the facet manager using the
                |             
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved action 
                |     Example:
                |         This example retrieves in Obj1 the fifth facet manager in the
                |         collection and in Obj2 the facet manager named IMC.
                | 
                |          Dim Obj1 As FunctFacetManager
                |          Set Obj1 = Desc.FacetManagers.Elem(5)
                |          Dim Obj2 As FunctFacetManager
                |          Set Obj2 = Desc.FacetManagers.Elem("IMC")

        :param cat_variant i_index:
        :rtype: FunctionalFacetMgr
        """
        return FunctionalFacetMgr(self.funct_facet_managers.Elem(i_index))

    def __repr__(self):
        return f'FunctFacetManagers(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import TYPE_CHECKING

from pycatia.in_interfaces.move import Move
from pycatia.in_interfaces.position import Position
from pycatia.navigator_interfaces.group import Group
from pycatia.system_interfaces.any_object import AnyObject

if TYPE_CHECKING:
    from pycatia.fitting_interfaces.shuttles import Shuttles


class Shuttle(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Shuttle
                | 
                | The interface to access a CATIAShuttle.
                | Role: The shuttle object is used to define a grouping of products. Once
                | products have been placed in the shuttle then they can be moved all at once.
                | Also the shuttle has a base location defined by the shuttle
                | axis.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.shuttle = com_object

    @property
    def angle_limit(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AngleLimit() As double
                | 
                |     Returns/Stores the angle limit attribute. Role:/b> Retrieves/stores the
                |     shuttle's angle limit attribute.

        :rtype: float
        """

        return self.shuttle.AngleLimit

    @angle_limit.setter
    def angle_limit(self, value: float):
        """
        :param float value:
        """

        self.shuttle.AngleLimit = value

    @property
    def angle_validation(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AngleValidation() As boolean
                | 
                |     Returns/Stores the angle validation attribute. Role:/b> Retrieves/stores
                |     the shuttle's angle validation attribute.

        :rtype: bool
        """

        return self.shuttle.AngleValidation

    @angle_validation.setter
    def angle_validation(self, value: bool):
        """
        :param bool value:
        """

        self.shuttle.AngleValidation = value

    @property
    def group(self) -> Group:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Group() As Group
                | 
                |     Returns or sets the associated group object. Role:/b> Retrieves/stores the
                |     objects within the shuttle as a group, that is a CATIAGroup.

        :rtype: Group
        """

        return Group(self.shuttle.Group)

    @group.setter
    def group(self, value: Group):
        """
        :param Group value:
        """

        self.shuttle.Group = value

    @property
    def move(self) -> Move:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Move() As Move (Read Only)
                | 
                |     Returns the shuttle's move object. The move object is aggregated by the
                |     shuttle object and itself aggregates a movable object to which you can apply a
                |     move transformation by means of an isometry matrix. It moves your shuttle
                |     according to this isometry.
                | 
                |     Example:
                | 
                |           This example retrieves the move object for the
                |          Engine shuttle.
                |          
                | 
                |          Dim EngineMoveObject As Move
                |          Set EngineMoveObject = Engine.Move

        :rtype: Move
        """

        return Move(self.shuttle.Move)

    @property
    def move_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MoveMode() As CatShuttleMoveMode
                | 
                |     Returns/Stores the shuttle move mode. Role:/b> Retrieves/stores the shuttle
                |     move mode. This can be either shuttle mode (to move the shuttle) or axis mode
                |     (to simply move the shuttle axis).

        :return: enum cat_shuttle_move_mode
        :rtype: int
        """

        return self.shuttle.MoveMode

    @move_mode.setter
    def move_mode(self, value: int):
        """
        :param int value: enum cat_shuttle_move_mode
        """

        self.shuttle.MoveMode = value

    @property
    def position(self) -> Position:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Position() As Position (Read Only)
                | 
                |     Returns the shuttle's position object. The position object is the object
                |     aggregated by the ahuttle object that holds the position of the shuttle in the
                |     space.
                | 
                |     Example:
                | 
                |           This example retrieves the position object for the
                |          Engine shuttle.
                |          
                | 
                |          Dim EnginePositionObject As Position
                |          Set EnginePositionObject = Engine.Position

        :rtype: Position
        """

        return Position(self.shuttle.Position)

    @property
    def reference(self) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Reference() As CATBaseDispatch
                | 
                |     Returns or sets the associated reference object. Role:/b> Retrieves/stores
                |     the shuttle's reference object.

        :rtype: AnyObject
        """

        return AnyObject(self.shuttle.Reference)

    @reference.setter
    def reference(self, value: AnyObject):
        """
        :param AnyObject value:
        """

        self.shuttle.Reference = value

    @property
    def sub_shuttles(self) -> 'Shuttles':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SubShuttles() As Shuttles (Read Only)
                | 
                |     Returns any shuttles that are contained within the current shuttle.
                |     Role:/b> Returns any shuttles that are contained within the current shuttle.

        :rtype: Shuttles
        """

        from pycatia.fitting_interfaces.shuttles import Shuttles
        return Shuttles(self.shuttle.SubShuttles)

    @property
    def vector(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Vector() As CatShuttleVector
                | 
                |     Returns/Stores the validation vector attribute. Role:/b> Retrieves/stores
                |     the validation vector attribute.

        :return: enum cat_shuttle_vector
        :rtype: int
        """

        return self.shuttle.Vector

    @vector.setter
    def vector(self, value: int):
        """
        :param int value: enum cat_shuttle_vector
        """

        self.shuttle.Vector = value

    def __repr__(self):
        return f'Shuttle(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.document import Document
from pycatia.navigator_interfaces.group import Group
from pycatia.product_structure_interfaces.product import Product
from pycatia.smt_interfaces.wrapping import Wrapping
from pycatia.system_interfaces.collection import Collection


class Wrappings(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Wrappings
                | 
                | Interface to compute Wrappings
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=Wrapping)
        self.wrappings = com_object

    def add(
            self,
            i_product_to_wrapping: Product,
            i_accuracy: float,
            i_ratio: float,
            i_shape_name: str,
            i_activated_shape: int,
            i_default_shape: int
    ) -> Wrapping:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add(Product iProductToWrapping,
                | double iAccuracy,
                | double iRatio,
                | CATBSTR iShapeName,
                | long iActivatedShape,
                | long iDefaultShape) As Wrapping
                | 
                |     Compute a wrapping on the selected products. This method is
                |     deprecated!
                | 
                |     Parameters:
                | 
                |         iProductToWrapping
                |             The selected products on which you want to perform a wrapping.
                |             
                |         iAccuracy
                |             The grain accuracy. 
                |         iRatio
                |             The ratio. 
                |         iShapeName
                |             The associated shape name. 
                |         iActivatedShape
                |             Do we activate the shape ? 
                |         iDefaultShape
                |             Do we activate the shape as default shape ? 
                | 
                |     Returns:
                |         oWrapping: Document containing the result.

        :param Product i_product_to_wrapping:
        :param float i_accuracy:
        :param float i_ratio:
        :param str i_shape_name:
        :param int i_activated_shape:
        :param int i_default_shape:
        :rtype: Wrapping
        """
        return Wrapping(
            self.wrappings.Add(
                i_product_to_wrapping.com_object,
                i_accuracy,
                i_ratio,
                i_shape_name,
                i_activated_shape,
                i_default_shape
            )
        )

    def clean_up(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CleanUp()
                | 
                |     Cleans up.

        :rtype: None
        """
        return self.wrappings.CleanUp()

    def compute_a_wrapping(
            self,
            group_of_selected_products: Group,
            i_accuracy: float,
            i_ration: float,
            i_accuracy_for_simplification: float
    ) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ComputeAWrapping(Group GroupOfSelectedProducts,
                | double iAccuracy,
                | double iRation,
                | double iAccuracyForSimplification) As Document
                | 
                |     Compute a wrapping on the selected products.
                | 
                |     Parameters:
                | 
                |         GroupOfSelectedProducts
                |             The selected products on which you want to perform a wrapping.
                |             
                |         iAccuracy
                |             The grain accuracy. 
                |         iRation
                |             The ratio. 
                |         iAccuracyForSimplification
                |             The accuracy for the simplification. equals -1 if no simplification
                |             is to be performed. 
                | 
                |     Returns:
                |         WrappingDocument: Document containing the result.

        :param Group group_of_selected_products:
        :param float i_accuracy:
        :param float i_ration:
        :param float i_accuracy_for_simplification:
        :rtype: Document
        """
        return Document(
            self.wrappings.ComputeAWrapping(
                group_of_selected_products.com_object,
                i_accuracy,
                i_ration,
                i_accuracy_for_simplification
            )
        )

    def compute_a_wrapping_with_a_reference(
            self,
            i_group_of_selected_products: Group,
            i_reference_product: Product,
            i_accuracy: float,
            i_ration: float,
            i_accuracy_for_simplification: float
    ) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ComputeAWrappingWithAReference(Group
                | iGroupOfSelectedProducts,
                | Product iReferenceProduct,
                | double iAccuracy,
                | double iRation,
                | double iAccuracyForSimplification) As Document
                | 
                |     Compute a wrapping on the selected products, according to a reference
                |     product.
                | 
                |     Parameters:
                | 
                |         GroupOfSelectedProducts
                |             The selected products on which you want to perform a wrapping.
                |             
                |         iReferenceProduct
                |             Product taken as a reference. 
                |         iAccuracy
                |             The grain accuracy. 
                |         iRation
                |             The ratio. 
                |         iAccuracyForSimplification
                |             The accuracy for the simplification. equals -1 if no simplification
                |             is to be performed. 
                | 
                |     Returns:
                |         WrappingDocument: Document containing the result.

        :param Group i_group_of_selected_products:
        :param Product i_reference_product:
        :param float i_accuracy:
        :param float i_ration:
        :param float i_accuracy_for_simplification:
        :rtype: Document
        """
        return Document(
            self.wrappings.ComputeAWrappingWithAReference(
                i_group_of_selected_products.com_object,
                i_reference_product.com_object,
                i_accuracy,
                i_ration,
                i_accuracy_for_simplification
            )
        )

    def wrapping_shape_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func WrappingShapeName() As CATBSTR
                | 
                |     Returns the name of the associated shape.

        :rtype: str
        """
        return self.wrappings.WrappingShapeName()

    def __repr__(self):
        return f'Wrappings(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.drafting_interfaces.drawing_leaders import DrawingLeaders
from pycatia.drafting_interfaces.drawing_text_properties import DrawingTextProperties
from pycatia.drafting_interfaces.drawing_text_range import DrawingTextRange
from pycatia.system_interfaces.any_object import AnyObject


class DrawingWelding(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DrawingWelding
                | 
                | Represents a drawing welding in a drawing view.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.drawing_welding = com_object

    @property
    def angle(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Angle() As double
                | 
                |     Returns or sets the angle of the drawing text. The angle is measured
                |     between the axis system of the drawing view and the local axis system of the
                |     drawing text. The angle is measured in radians and is counted
                |     counterclockwise.
                | 
                |     Example:
                |         This example sets the angle of the MyText drawing Text to 90 degrees
                |         clockwise. You first need to compute the angle in degrees and set the minus
                |         sign to indicate the rotation is clockwise.
                | 
                |          Angle90Clockwise = -90
                |          MyText.Angle = Angle90Clockwise

        :rtype: float
        """

        return self.drawing_welding.Angle

    @angle.setter
    def angle(self, value: float):
        """
        :param float value:
        """

        self.drawing_welding.Angle = value

    @property
    def identification_line_side(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property IdentificationLineSide() As CatWeldingSide
                | 
                |     Returns or sets the welding identification line Side of the drawing welding
                |     symbol.
                |     Precondition: This property is only available for ISO
                |     standard.
                | 
                |     Example:
                |         This example sets welding identification line Side to Up
                |         .
                | 
                |          MyWeld.IdentificationLineSide = catWeldingUp

        :return: enum cat_welding_side
        :rtype: int
        """

        return self.drawing_welding.IdentificationLineSide

    @identification_line_side.setter
    def identification_line_side(self, value: int):
        """
        :param int value: enum cat_welding_side
        """

        self.drawing_welding.IdentificationLineSide = value

    @property
    def leaders(self) -> DrawingLeaders:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Leaders() As DrawingLeaders (Read Only)
                | 
                |     Returns the drawing leader collection of the drawing
                |     welding.
                | 
                |     Example:
                |         This example retrieves in LeaderCollection the collection of leaders of
                |         the MyWelding drawing welding.
                | 
                |          Dim LeaderCollection As DrawingLeaders
                |          Set LeaderCollection = MyWelding.Leaders

        :rtype: DrawingLeaders
        """

        return DrawingLeaders(self.drawing_welding.Leaders)

    @property
    def text_properties(self) -> DrawingTextProperties:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property TextProperties() As DrawingTextProperties (Read
                | Only)
                | 
                |     Returns the text properties of the drawing welding.
                | 
                |     Example:
                |         This example retrieves in TextProperties the text properties of the
                |         MyWelding drawing welding..
                | 
                |          Dim TextProperties As DrawingTextProperties
                |          Set TextProperties = MyWelding.TextProperties

        :rtype: DrawingTextProperties
        """

        return DrawingTextProperties(self.drawing_welding.TextProperties)

    @property
    def welding_side(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property WeldingSide() As CatWeldingSide
                | 
                |     Returns or sets the welding side of the drawing welding
                |     symbol.
                | 
                |     Example:
                |         This example sets welding side to Up .
                | 
                |          MyWeld.WeldingSide = catWeldingUp

        :return: enum cat_welding_side
        :rtype: int
        """

        return self.drawing_welding.WeldingSide

    @welding_side.setter
    def welding_side(self, value: int):
        """
        :param int value: enum cat_welding_side
        """

        self.drawing_welding.WeldingSide = value

    @property
    def welding_tail(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property WeldingTail() As CatDftWeldingTail
                | 
                |     Returns or sets the welding tail of the drawing welding
                |     symbol.
                | 
                |     Example:
                |         This example displays the welding symbol tail.
                | 
                |          MyWeld.WeldingTail = catDftWeldingTailYES

        :return: enum cat_dft_welding_tail
        :rtype: int
        """

        return self.drawing_welding.WeldingTail

    @welding_tail.setter
    def welding_tail(self, value: int):
        """
        :param int value: enum cat_dft_welding_tail
        """

        self.drawing_welding.WeldingTail = value

    @property
    def x(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property x() As double
                | 
                |     Returns or sets the x coordinate of the drawing welding. It is expressed
                |     with respect to the current view coordinate system. This coordinate, like any
                |     length, is measured in millimeters.
                | 
                |     Example:
                |         This example retrieves in X the x coordinate of the MyWelding drawing
                |         welding.
                | 
                |          X = MyWelding.x

        :rtype: float
        """

        return self.drawing_welding.x

    @x.setter
    def x(self, value: float):
        """
        :param float value:
        """

        self.drawing_welding.x = value

    @property
    def y(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property y() As double
                | 
                |     Returns or sets the y coordinate of the drawing welding. It is expressed
                |     with respect to the current view coordinate system. This coordinate, like any
                |     length, is measured in millimeters.
                | 
                |     Example:
                |         This example sets the y coordinate of the MyWelding drawing welding to
                |         5 inches. You need first to convert the 5 inches into
                |         millmeters.
                | 
                |          NewYCoordinate = 5*25.4/1000
                |          MyWelding.y = NewYCoordinate

        :rtype: float
        """

        return self.drawing_welding.y

    @y.setter
    def y(self, value: float):
        """
        :param float value:
        """

        self.drawing_welding.y = value

    def get_additional_symbol(self, i_weld: int) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetAdditionalSymbol(CatWelding iWeld) As
                | CatWeldAdditionalSymbol
                | 
                |     Returns the additional symbol of the drawing welding.
                | 
                |     Parameters:
                | 
                |         iWeld
                |             The xxx
                | 
                |             Example:
                |                 This example sets an concave additinal symbol on the MyWelding
                |                 drawing welding
                | 
                |                  MyWelding.Symbol = DftConcaveSymbol

        :param int i_weld:
        :return: enum cat_welding
        :rtype: int
        """
        return self.drawing_welding.GetAdditionalSymbol(i_weld)

    def get_finish_symbol(self, i_weld: int) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetFinishSymbol(CatWelding iWeld) As
                | CatDftWeldFinishSymbol
                | 
                |     Returns the finish symbol of the drawing welding.
                | 
                |     Parameters:
                | 
                |         iWeld
                |             The field on which finish symbol is applied.
                | 
                |             Example:
                |                 This example returns the finish symbol on the first symbol of
                |                 the MyWelding drawing welding
                | 
                |                  MyWelding.GetFinishSymbol(catWeldingFieldOne,oFinishSymbol)

        :param int i_weld: enum cat_welding
        :return: enum cat_dft_weld_finish_symbol
        :rtype: int
        """
        return self.drawing_welding.GetFinishSymbol(i_weld)

    def get_symbol(self, i_weld: int) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetSymbol(CatWelding iWeld) As CatWeldingSymbol
                | 
                |     Returns the symbol of the drawing welding.
                | 
                |     Parameters:
                | 
                |         iWeld
                |             The field on which the symbol is applied 
                |         oSymbol
                |             The welding symbol
                | 
                |             Example:
                |                 This example gets the symbol on the first field of the
                |                 MyWelding drawing welding
                | 
                |                  MyWelding.GetSymbol(catWeldingFieldOne,oSymbol)

        :param int i_weld: enum cat_welding
        :return: enum cat_welding_symbol
        :rtype: int
        """
        return self.drawing_welding.GetSymbol(i_weld)

    def get_text_range(self, i_field: int) -> DrawingTextRange:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetTextRange(CatWeldingField iField) As
                | DrawingTextRange
                | 
                |     Returns the field of the drawing welding in a drawing text
                |     range.
                | 
                |     Parameters:
                | 
                |         iField
                |             The drawing welding field 
                | 
                |     Returns:
                |         The drawing text range that corresponds to the drawing welding field
                |         
                | 
                | Example:
                |     This example retrieves the xxx.
                | 
                |      Dim textRange As DrawingTextRange
                |      Set textRange = MyWelding.GetTextRange (catWeldingUp)

        :param int i_field: enum cat_welding_field
        :rtype: DrawingTextRange
        """
        return DrawingTextRange(self.drawing_welding.GetTextRange(i_field))

    def set_additional_symbol(self, i_symbol: int, i_weld: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetAdditionalSymbol(CatWeldAdditionalSymbol iSymbol,
                | CatWelding iweld)
                | 
                |     Sets the additional symbol of the drawing welding.
                | 
                |     Parameters:
                | 
                |         iSymbol
                |             The welding additional symbol 
                |         iWeld
                |             The xxx
                | 
                |             Example:
                |                 This example sets an concave additinal symbol on the MyWelding
                |                 drawing welding
                | 
                |                  MyWelding.Symbol = DftConcaveSymbol

        :param int i_symbol: enum cat_weld_additional_symbol
        :param int i_weld: enum cat_welding
        :rtype: None
        """
        return self.drawing_welding.SetAdditionalSymbol(i_symbol, i_weld)

    def set_finish_symbol(self, i_finish_symbol: int, i_weld: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetFinishSymbol(CatDftWeldFinishSymbol iFinishSymbol,
                | CatWelding iWeld)
                | 
                |     Sets the finish symbol of the drawing welding.
                | 
                |     Parameters:
                | 
                |         iFinishSymbol
                |             The finish welding symbol 
                |         iWeld
                |             The field on which finish symbol will be applied.
                | 
                |             Example:
                |                 This example sets the finish symbol on the first symbol of the
                |                 MyWelding drawing welding
                | 
                |                 
                |                 MyWelding.GetFinishSymbol(catWeldingFieldOne,catDftLetterCWelding)

        :param int i_finish_symbol: enum cat_dft_weld_finish_symbol
        :param int i_weld: enum cat_welding
        :rtype: None
        """
        return self.drawing_welding.SetFinishSymbol(i_finish_symbol, i_weld)

    def set_symbol(self, i_symbol: int, i_weld: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetSymbol(CatWeldingSymbol iSymbol,
                | CatWelding iweld)
                | 
                |     Sets the symbol of the drawing welding.
                | 
                |     Parameters:
                | 
                |         iSymbol
                |             The welding symbol 
                |         iWeld
                |             The field on which the symbol is applied
                | 
                |             Example:
                |                 This example sets a symbol on the first field of the MyWelding
                |                 drawing welding
                | 
                |                  MyWelding.SetSymbol(catSquareWelding,catWeldingFieldOne)

        :param int i_symbol: enum cat_welding_symbol
        :param int i_weld: enum cat_welding
        :rtype: None
        """
        return self.drawing_welding.SetSymbol(i_symbol, i_weld)

    def __repr__(self):
        return f'DrawingWelding(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class DevAnalysisSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         DevAnalysisSettingAtt
                | 
                | Interface to handle parameters of Infrastructure-DELMIA Infrastructure-Device
                | Analysis Tools Options Tab page.
                | Role: This interface is implemented by a component which represents the
                | controller of Device Analysis Tools Options parameter
                | settings.
                | 
                |     Methods to set value of each parameter xxx
                |     Methods to get value of each parameter xxx
                |     Methods to get information on each parameter xxx
                |     Methods to lock/unlock value of each parameter xxx
                | 
                | Here is the list of parameters to use and their meaning:
                | 
                |     TravelLimit: defines what behavior you can expect when the DOF travel
                |     limits are exeeded.
                |     VelocityLimit: defines what behavior you can expect when the DOF speed
                |     limits are exeeded.
                |     AccelLimit: defines what behavior you can expect when the DOF acceleration
                |     limits are exeeded.
                |     CautionZone: defines what behavior you can expect when the DOF caution zone
                |     limits are exeeded.
                |     TravelColor: defines the highlight color to be used when the DOF travel
                |     limits are exceeded.
                |     VelocityColor: defines the highlight color to be used when the DOF speed
                |     limits are exceeded.
                |     AccelColor: defines the highlight color to be used when the DOF
                |     acceleration limits are exceeded.
                |     CautionColor: defines the highlight color to be used when the DOF caution
                |     zone limits are exceeded.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.dev_analysis_setting_att = com_object

    def get_accel_colour_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAccelColorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AccelColor
                |     parameter.
                |     Role:Retrieves the state of the AccelColor parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.dev_analysis_setting_att.GetAccelColorInfo(io_admin_level, io_locked)

    def get_accel_limit_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAccelLimitInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AccelLimit
                |     parameter.
                |     Role:Retrieves the state of the AccelLimit parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.dev_analysis_setting_att.GetAccelLimitInfo(io_admin_level, io_locked)

    def get_caution_colour_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetCautionColorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the CautionColor
                |     parameter.
                |     Role:Retrieves the state of the CautionColor parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.dev_analysis_setting_att.GetCautionColorInfo(io_admin_level, io_locked)

    def get_caution_zone_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetCautionZoneInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the CautionZone
                |     parameter.
                |     Role:Retrieves the state of the CautionZone parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.dev_analysis_setting_att.GetCautionZoneInfo(io_admin_level, io_locked)

    def get_tool_tip_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetToolTipModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ToolTipMode
                |     parameter.
                |     Role:Retrieves the state of the ToolTipMode parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.dev_analysis_setting_att.GetToolTipModeInfo(io_admin_level, io_locked)

    def get_travel_colour_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTravelColorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the TravelColor
                |     parameter.
                |     Role:Retrieves the state of the TravelColor parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.dev_analysis_setting_att.GetTravelColorInfo(io_admin_level, io_locked)

    def get_travel_limit_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTravelLimitInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the TravelLimit
                |     parameter.
                |     Role:Retrieves the state of the TravelLimit parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.dev_analysis_setting_att.GetTravelLimitInfo(io_admin_level, io_locked)

    def get_velocity_colour_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetVelocityColorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the VelocityColor
                |     parameter.
                |     Role:Retrieves the state of the VelocityColor parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.dev_analysis_setting_att.GetVelocityColorInfo(io_admin_level, io_locked)

    def get_velocity_limit_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetVelocityLimitInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the VelocityLimit
                |     parameter.
                |     Role:Retrieves the state of the VelocityLimit parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.dev_analysis_setting_att.GetVelocityLimitInfo(io_admin_level, io_locked)

    def set_accel_colour_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAccelColorLock(boolean iLocked)
                | 
                |     Locks or unlocks the AccelColor parameter.
                |     Role:Locks or unlocks the AccelColor parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.dev_analysis_setting_att.SetAccelColorLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_accel_color_lock'
        # # vba_code = """
        # # Public Function set_accel_color_lock(dev_analysis_setting_att)
        # #     Dim iLocked (2)
        # #     dev_analysis_setting_att.SetAccelColorLock iLocked
        # #     set_accel_color_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_accel_limit_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAccelLimitLock(boolean iLocked)
                | 
                |     Locks or unlocks the AccelLimit parameter.
                |     Role:Locks or unlocks the AccelLimit parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.dev_analysis_setting_att.SetAccelLimitLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_accel_limit_lock'
        # # vba_code = """
        # # Public Function set_accel_limit_lock(dev_analysis_setting_att)
        # #     Dim iLocked (2)
        # #     dev_analysis_setting_att.SetAccelLimitLock iLocked
        # #     set_accel_limit_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_caution_colour_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCautionColorLock(boolean iLocked)
                | 
                |     Locks or unlocks the CautionColor parameter.
                |     Role:Locks or unlocks the CautionColor parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.dev_analysis_setting_att.SetCautionColorLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_caution_color_lock'
        # # vba_code = """
        # # Public Function set_caution_color_lock(dev_analysis_setting_att)
        # #     Dim iLocked (2)
        # #     dev_analysis_setting_att.SetCautionColorLock iLocked
        # #     set_caution_color_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_caution_zone_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCautionZoneLock(boolean iLocked)
                | 
                |     Locks or unlocks the CautionZone parameter.
                |     Role:Locks or unlocks the CautionZone parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.dev_analysis_setting_att.SetCautionZoneLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_caution_zone_lock'
        # # vba_code = """
        # # Public Function set_caution_zone_lock(dev_analysis_setting_att)
        # #     Dim iLocked (2)
        # #     dev_analysis_setting_att.SetCautionZoneLock iLocked
        # #     set_caution_zone_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_tool_tip_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetToolTipModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the ToolTipMode parameter.
                |     Role:Locks or unlocks the ToolTipMode parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.dev_analysis_setting_att.SetToolTipModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_tool_tip_mode_lock'
        # # vba_code = """
        # # Public Function set_tool_tip_mode_lock(dev_analysis_setting_att)
        # #     Dim iLocked (2)
        # #     dev_analysis_setting_att.SetToolTipModeLock iLocked
        # #     set_tool_tip_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_travel_colour_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTravelColorLock(boolean iLocked)
                | 
                |     Locks or unlocks the TravelColor parameter.
                |     Role:Locks or unlocks the TravelColor parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.dev_analysis_setting_att.SetTravelColorLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_travel_color_lock'
        # # vba_code = """
        # # Public Function set_travel_color_lock(dev_analysis_setting_att)
        # #     Dim iLocked (2)
        # #     dev_analysis_setting_att.SetTravelColorLock iLocked
        # #     set_travel_color_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_travel_limit_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetTravelLimitLock(boolean iLocked)
                | 
                |     Locks or unlocks the TravelLimit parameter.
                |     Role:Locks or unlocks the TravelLimit parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.dev_analysis_setting_att.SetTravelLimitLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_travel_limit_lock'
        # # vba_code = """
        # # Public Function set_travel_limit_lock(dev_analysis_setting_att)
        # #     Dim iLocked (2)
        # #     dev_analysis_setting_att.SetTravelLimitLock iLocked
        # #     set_travel_limit_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_velocity_colour_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetVelocityColorLock(boolean iLocked)
                | 
                |     Locks or unlocks the VelocityColor parameter.
                |     Role:Locks or unlocks the VelocityColor parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.dev_analysis_setting_att.SetVelocityColorLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_velocity_color_lock'
        # # vba_code = """
        # # Public Function set_velocity_color_lock(dev_analysis_setting_att)
        # #     Dim iLocked (2)
        # #     dev_analysis_setting_att.SetVelocityColorLock iLocked
        # #     set_velocity_color_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_velocity_limit_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetVelocityLimitLock(boolean iLocked)
                | 
                |     Locks or unlocks the VelocityLimit parameter.
                |     Role:Locks or unlocks the VelocityLimit parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.dev_analysis_setting_att.SetVelocityLimitLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_velocity_limit_lock'
        # # vba_code = """
        # # Public Function set_velocity_limit_lock(dev_analysis_setting_att)
        # #     Dim iLocked (2)
        # #     dev_analysis_setting_att.SetVelocityLimitLock iLocked
        # #     set_velocity_limit_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'DevAnalysisSettingAtt(name="{self.name}")'
